/*!
 * rollup-plugin-magic-string - magic-string plugin for rollup
 * Version 1.0.3
 * Copyright (c) 2020 Adriaan Callaerts <adriaan.callaerts@gmail.com>
 * Released under the MIT license
 *
 * Source code: [object Object]
 */
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var rollupPluginutils = require('rollup-pluginutils');
var MagicString = _interopDefault(require('magic-string'));

function objectWithoutProperties (obj, exclude) { var target = {}; for (var k in obj) if (Object.prototype.hasOwnProperty.call(obj, k) && exclude.indexOf(k) === -1) target[k] = obj[k]; return target; }

function rollupPluginMagicString(ref) {
  var magic = ref.magic;
  var rest = objectWithoutProperties( ref, ["magic"] );
  var options = rest;

  if (!Object.prototype.isPrototypeOf.bind(Function.prototype)(magic)) {
    throw new TypeError('options.magic is required')
  }
  var filter = rollupPluginutils.createFilter(options.include, options.exclude);
  return {
    name: 'magic-string',
    transform: function transform(code, id) {
      if (!filter(id)) { return undefined }
      var magicString = new MagicString(code);
      magic(code, id, magicString);
      var result = { code: magicString.toString() };
      if (options.sourcemap !== false) {
        result.map = magicString.generateMap({ hires: true });
      }
      return result
    },
  }
}

function append(string, options) {
  if ( options === void 0 ) options = {};

  return rollupPluginMagicString(Object.assign({}, {magic: function magic(_code, _id, magicString) {
      magicString.append(string);
    }},
    options))
}

function prepend(string, options) {
  if ( options === void 0 ) options = {};

  return rollupPluginMagicString(Object.assign({}, {magic: function magic(_code, _id, magicString) {
      magicString.prepend(string);
    }},
    options))
}

function wrap(pre, post, options) {
  if ( options === void 0 ) options = {};

  return rollupPluginMagicString(Object.assign({}, {magic: function magic(_code, _id, magicString) {
      magicString.prepend(pre);
      magicString.append(post);
    }},
    options))
}

exports.append = append;
exports.default = rollupPluginMagicString;
exports.prepend = prepend;
exports.wrap = wrap;

module.exports = Object.assign(exports.default, exports)
